# ItemV20

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**put_code** | **str** |  | [optional] 
**item_type** | **str** |  | 
**item_name** | **str** |  | 
**external_id** | [**ExternalIDV20**](ExternalIDV20.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

